if [ -x /usr/bin/install-info ] ; then
  chroot . /usr/bin/install-info --info-dir=/usr/info /usr/info/preview-latex.info.gz 2>/dev/null
  chroot . /usr/bin/install-info --info-dir=/usr/info /usr/info/auctex.info.gz 2>/dev/null
fi

